@@ -31,6 +31,8 @@ class ManageHeaderBar;
 class QQmlEngine;
 class ElisaApplicationPrivate;
 class QSessionManager;
+class KColorSchemeManager;
+class QAbstractItemModel;
 
 class ELISALIB_EXPORT ElisaApplication : public QObject
 {
@@ -84,6 +86,14 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
                READ showSystemTrayIcon
                NOTIFY showSystemTrayIconChanged)
 
+    Q_PROPERTY(QAbstractItemModel* colorSchemesModel
+               READ colorSchemesModel
+               CONSTANT)
+
+    Q_PROPERTY(int initialViewIndex
+               READ initialViewIndex
+               NOTIFY initialViewIndexChanged)
+
 public:
     explicit ElisaApplication(QObject *parent = nullptr);
 
@@ -95,29 +105,33 @@ public:
 
     Q_INVOKABLE void installKeyEventFilter(QObject *object);
 
+    Q_INVOKABLE void showInFolder(QUrl filePath);
+
     bool eventFilter(QObject *object, QEvent *event) override;
 
-    const DataTypes::EntryDataList &arguments() const;
+    [[nodiscard]] const DataTypes::EntryDataList &arguments() const;
 
-    MusicListenersManager *musicManager() const;
+    [[nodiscard]] MusicListenersManager *musicManager() const;
 
-    MediaPlayList *mediaPlayList() const;
+    [[nodiscard]] MediaPlayList *mediaPlayList() const;
 
-    MediaPlayListProxyModel *mediaPlayListProxyModel() const;
+    [[nodiscard]] MediaPlayListProxyModel *mediaPlayListProxyModel() const;
 
-    AudioWrapper *audioPlayer() const;
+    [[nodiscard]] AudioWrapper *audioPlayer() const;
 
-    ManageAudioPlayer *audioControl() const;
+    [[nodiscard]] ManageAudioPlayer *audioControl() const;
 
-    ManageMediaPlayerControl *playerControl() const;
+    [[nodiscard]] ManageMediaPlayerControl *playerControl() const;
 
-    ManageHeaderBar *manageHeaderBar() const;
+    [[nodiscard]] ManageHeaderBar *manageHeaderBar() const;
 
-    bool showProgressOnTaskBar() const;
+    [[nodiscard]] bool showProgressOnTaskBar() const;
 
-    bool showSystemTrayIcon() const;
+    [[nodiscard]] bool showSystemTrayIcon() const;
 
-    ElisaUtils::PlayListEntryType embeddedView() const;
+    [[nodiscard]] ElisaUtils::PlayListEntryType embeddedView() const;
+
+    int initialViewIndex() const;
 
 Q_SIGNALS:
 
@@ -151,6 +165,8 @@ Q_SIGNALS:
 
     void embeddedViewChanged();
 
+    void initialViewIndexChanged();
+
 public Q_SLOTS:
 
     void appHelpActivated();
@@ -173,6 +189,8 @@ public Q_SLOTS:
 
     void initialize();
 
+    void activateColorScheme(const QString &name);
+
 public:
 
     void setQmlEngine(QQmlEngine *engine);
@@ -193,6 +211,10 @@ private Q_SLOTS:
 
     void configChanged();
 
+    void nextTrack();
+
+    void previousTrack();
+
 private:
 
     void initializeModels();
@@ -201,9 +223,11 @@ private:
 
     void setupActions(const QString &actionName);
 
-    DataTypes::EntryDataList checkFileListAndMakeAbsolute(const DataTypes::EntryDataList &filesList,
+    [[nodiscard]] DataTypes::EntryDataList checkFileListAndMakeAbsolute(const DataTypes::EntryDataList &filesList,
                                                               const QString &workingDirectory) const;
 
+    QAbstractItemModel *colorSchemesModel();
+
     std::unique_ptr<ElisaApplicationPrivate> d;
 
 };
